@@ -1174,12 +1174,10 @@ impl Resolver {
         } else if mcu.starts_with("stm32g0")
             || mcu.starts_with("stm32l0")
             || mcu.starts_with("stm32f0")
+            || mcu.starts_with("nrf51")
         {
             // ARM Cortex-M0/M0+
             "thumbv6m-none-eabi"
-        } else if mcu.starts_with("nrf51") {
-            // ARM Cortex-M0/M0+
-            "thumbv6m-none-eabi"
         } else if mcu.starts_with("nrf52") {
             // ARM Cortex-M4F
             "thumbv7em-none-eabihf"
